@@ -1,11 +1,11 @@
-use crate::errors::ErrorMode;
 use pyo3::exceptions::{PyException, PyValueError};
 use pyo3::prelude::*;
 use pyo3::types::{PyDict, PyString};
 
-use crate::input::Input;
+use crate::input::InputType;
 use crate::tools::extract_i64;
 
+use super::line_error::AsErrorValue;
 use super::{ErrorType, ValError};
 
 #[pyclass(extends=PyException, module="pydantic_core._pydantic_core")]
@@ -73,7 +73,7 @@ impl PydanticCustomError {
         }
     }
 
-    #[getter(type)]
+    #[getter(r#type)]
     pub fn error_type(&self) -> String {
         self.error_type.clone()
     }
@@ -106,7 +106,7 @@ impl PydanticCustomError {
 }
 
 impl PydanticCustomError {
-    pub fn into_val_error<'a>(self, input: &'a impl Input<'a>) -> ValError<'a> {
+    pub fn into_val_error(self, input: &impl AsErrorValue) -> ValError {
         let error_type = ErrorType::CustomError {
             error_type: self.error_type,
             message_template: self.message_template,
@@ -122,7 +122,7 @@ impl PydanticCustomError {
                 let key: &PyString = key.downcast()?;
                 if let Ok(py_str) = value.downcast::<PyString>() {
                     message = message.replace(&format!("{{{}}}", key.to_str()?), py_str.to_str()?);
-                } else if let Ok(value_int) = extract_i64(value) {
+                } else if let Some(value_int) = extract_i64(value) {
                     message = message.replace(&format!("{{{}}}", key.to_str()?), &value_int.to_string());
                 } else {
                     // fallback for anything else just in case
@@ -148,7 +148,7 @@ impl PydanticKnownError {
         Ok(Self { error_type })
     }
 
-    #[getter(type)]
+    #[getter(r#type)]
     pub fn error_type(&self) -> String {
         self.error_type.to_string()
     }
@@ -164,7 +164,7 @@ impl PydanticKnownError {
     }
 
     pub fn message(&self, py: Python) -> PyResult<String> {
-        self.error_type.render_message(py, &ErrorMode::Python)
+        self.error_type.render_message(py, InputType::Python)
     }
 
     fn __str__(&self, py: Python) -> PyResult<String> {
@@ -185,7 +185,7 @@ impl PydanticKnownError {
 }
 
 impl PydanticKnownError {
-    pub fn into_val_error<'a>(self, input: &'a impl Input<'a>) -> ValError<'a> {
+    pub fn into_val_error(self, input: &impl AsErrorValue) -> ValError {
         ValError::new(self.error_type, input)
     }
 }
