@@ -10,7 +10,6 @@ use pyo3::types::{
 use pyo3::types::{PyDictItems, PyDictKeys, PyDictValues};
 use pyo3::{intern, PyTypeInfo};
 
-use jiter::JsonValue;
 use speedate::MicrosecondsPrecisionOverflowBehavior;
 
 use crate::errors::{AsLocItem, ErrorType, ErrorTypeDefaults, InputValue, LocItem, ValError, ValResult};
@@ -26,8 +25,7 @@ use super::datetime::{
 };
 use super::return_enums::ValidationMatch;
 use super::shared::{
-    decimal_as_int, float_as_int, get_enum_meta_object, int_as_bool, map_json_err, str_as_bool, str_as_float,
-    str_as_int,
+    decimal_as_int, float_as_int, get_enum_meta_object, int_as_bool, str_as_bool, str_as_float, str_as_int,
 };
 use super::{
     py_string_str, BorrowInput, EitherBytes, EitherFloat, EitherInt, EitherString, EitherTimedelta, GenericArguments,
@@ -98,7 +96,7 @@ impl AsLocItem for PyAny {
     fn as_loc_item(&self) -> LocItem {
         if let Ok(py_str) = self.downcast::<PyString>() {
             py_str.to_string_lossy().as_ref().into()
-        } else if let Ok(key_int) = extract_i64(self) {
+        } else if let Some(key_int) = extract_i64(self) {
             key_int.into()
         } else {
             safe_repr(self).to_string().into()
@@ -106,9 +104,15 @@ impl AsLocItem for PyAny {
     }
 }
 
+impl AsLocItem for &'_ PyAny {
+    fn as_loc_item(&self) -> LocItem {
+        AsLocItem::as_loc_item(*self)
+    }
+}
+
 impl<'a> Input<'a> for PyAny {
-    fn as_error_value(&'a self) -> InputValue<'a> {
-        InputValue::PyAny(self)
+    fn as_error_value(&self) -> InputValue {
+        InputValue::Python(self.into())
     }
 
     fn identity(&self) -> Option<usize> {
@@ -154,7 +158,7 @@ impl<'a> Input<'a> for PyAny {
         self.is_callable()
     }
 
-    fn validate_args(&'a self) -> ValResult<'a, GenericArguments<'a>> {
+    fn validate_args(&'a self) -> ValResult<GenericArguments<'a>> {
         if let Ok(dict) = self.downcast::<PyDict>() {
             Ok(PyArgs::new(None, Some(dict)).into())
         } else if let Ok(args_kwargs) = self.extract::<ArgsKwargs>() {
@@ -170,7 +174,7 @@ impl<'a> Input<'a> for PyAny {
         }
     }
 
-    fn validate_dataclass_args(&'a self, class_name: &str) -> ValResult<'a, GenericArguments<'a>> {
+    fn validate_dataclass_args(&'a self, class_name: &str) -> ValResult<GenericArguments<'a>> {
         if let Ok(dict) = self.downcast::<PyDict>() {
             Ok(PyArgs::new(None, Some(dict)).into())
         } else if let Ok(args_kwargs) = self.extract::<ArgsKwargs>() {
@@ -189,22 +193,6 @@ impl<'a> Input<'a> for PyAny {
         }
     }
 
-    fn parse_json(&'a self) -> ValResult<'a, JsonValue> {
-        let bytes = if let Ok(py_bytes) = self.downcast::<PyBytes>() {
-            py_bytes.as_bytes()
-        } else if let Ok(py_str) = self.downcast::<PyString>() {
-            let str = py_string_str(py_str)?;
-            str.as_bytes()
-        } else if let Ok(py_byte_array) = self.downcast::<PyByteArray>() {
-            // Safety: from_slice does not run arbitrary Python code and the GIL is held so the
-            // bytes array will not be mutated while `JsonValue::parse` is reading it
-            unsafe { py_byte_array.as_bytes() }
-        } else {
-            return Err(ValError::new(ErrorTypeDefaults::JsonType, self));
-        };
-        JsonValue::parse(bytes, true).map_err(|e| map_json_err(self, e))
-    }
-
     fn validate_str(
         &'a self,
         strict: bool,
@@ -296,7 +284,7 @@ impl<'a> Input<'a> for PyAny {
         Err(ValError::new(ErrorTypeDefaults::BytesType, self))
     }
 
-    fn validate_bool(&self, strict: bool) -> ValResult<'_, ValidationMatch<bool>> {
+    fn validate_bool(&self, strict: bool) -> ValResult<ValidationMatch<bool>> {
         if let Ok(bool) = self.downcast::<PyBool>() {
             return Ok(ValidationMatch::exact(bool.is_true()));
         }
@@ -304,7 +292,7 @@ impl<'a> Input<'a> for PyAny {
         if !strict {
             if let Some(cow_str) = maybe_as_string(self, ErrorTypeDefaults::BoolParsing)? {
                 return str_as_bool(self, &cow_str).map(ValidationMatch::lax);
-            } else if let Ok(int) = extract_i64(self) {
+            } else if let Some(int) = extract_i64(self) {
                 return int_as_bool(self, int).map(ValidationMatch::lax);
             } else if let Ok(float) = self.extract::<f64>() {
                 if let Ok(int) = float_as_int(self, float) {
@@ -319,7 +307,7 @@ impl<'a> Input<'a> for PyAny {
         Err(ValError::new(ErrorTypeDefaults::BoolType, self))
     }
 
-    fn validate_int(&'a self, strict: bool) -> ValResult<'a, ValidationMatch<EitherInt<'a>>> {
+    fn validate_int(&'a self, strict: bool) -> ValResult<ValidationMatch<EitherInt<'a>>> {
         if self.is_exact_instance_of::<PyInt>() {
             return Ok(ValidationMatch::exact(EitherInt::Py(self)));
         } else if self.is_instance_of::<PyInt>() {
@@ -359,7 +347,7 @@ impl<'a> Input<'a> for PyAny {
         Err(ValError::new(ErrorTypeDefaults::IntType, self))
     }
 
-    fn validate_float(&'a self, strict: bool) -> ValResult<'a, ValidationMatch<EitherFloat<'a>>> {
+    fn validate_float(&'a self, strict: bool) -> ValResult<ValidationMatch<EitherFloat<'a>>> {
         if let Ok(float) = self.downcast_exact::<PyFloat>() {
             return Ok(ValidationMatch::exact(EitherFloat::Py(float)));
         }
@@ -647,7 +635,7 @@ impl<'a> Input<'a> for PyAny {
                     bytes_as_time(self, py_bytes.as_bytes(), microseconds_overflow_behavior)
                 } else if PyBool::is_exact_type_of(self) {
                     Err(ValError::new(ErrorTypeDefaults::TimeType, self))
-                } else if let Ok(int) = extract_i64(self) {
+                } else if let Some(int) = extract_i64(self) {
                     int_as_time(self, int, 0)
                 } else if let Ok(float) = self.extract::<f64>() {
                     float_as_time(self, float)
@@ -681,7 +669,7 @@ impl<'a> Input<'a> for PyAny {
                     bytes_as_datetime(self, py_bytes.as_bytes(), microseconds_overflow_behavior)
                 } else if PyBool::is_exact_type_of(self) {
                     Err(ValError::new(ErrorTypeDefaults::DatetimeType, self))
-                } else if let Ok(int) = extract_i64(self) {
+                } else if let Some(int) = extract_i64(self) {
                     int_as_datetime(self, int, 0)
                 } else if let Ok(float) = self.extract::<f64>() {
                     float_as_datetime(self, float)
@@ -718,7 +706,7 @@ impl<'a> Input<'a> for PyAny {
                     bytes_as_timedelta(self, str.as_bytes(), microseconds_overflow_behavior)
                 } else if let Ok(py_bytes) = self.downcast::<PyBytes>() {
                     bytes_as_timedelta(self, py_bytes.as_bytes(), microseconds_overflow_behavior)
-                } else if let Ok(int) = extract_i64(self) {
+                } else if let Some(int) = extract_i64(self) {
                     Ok(int_as_duration(self, int)?.into())
                 } else if let Ok(float) = self.extract::<f64>() {
                     Ok(float_as_duration(self, float)?.into())
