@@ -1,7 +1,6 @@
 use pyo3::prelude::*;
 use pyo3::types::{PyDict, PyString};
 
-use jiter::JsonValue;
 use speedate::MicrosecondsPrecisionOverflowBehavior;
 
 use crate::errors::{AsLocItem, ErrorTypeDefaults, InputValue, LocItem, ValError, ValResult};
@@ -12,7 +11,7 @@ use crate::validators::decimal::create_decimal;
 use super::datetime::{
     bytes_as_date, bytes_as_datetime, bytes_as_time, bytes_as_timedelta, EitherDate, EitherDateTime, EitherTime,
 };
-use super::shared::{map_json_err, str_as_bool, str_as_float};
+use super::shared::{str_as_bool, str_as_float};
 use super::{
     BorrowInput, EitherBytes, EitherFloat, EitherInt, EitherString, EitherTimedelta, GenericArguments, GenericIterable,
     GenericIterator, GenericMapping, Input, ValidationMatch,
@@ -34,7 +33,7 @@ impl<'py> ToPyObject for StringMapping<'py> {
 }
 
 impl<'py> StringMapping<'py> {
-    pub fn new_key(py_key: &'py PyAny) -> ValResult<'py, StringMapping> {
+    pub fn new_key(py_key: &'py PyAny) -> ValResult<StringMapping> {
         if let Ok(py_str) = py_key.downcast::<PyString>() {
             Ok(Self::String(py_str))
         } else {
@@ -42,7 +41,7 @@ impl<'py> StringMapping<'py> {
         }
     }
 
-    pub fn new_value(py_value: &'py PyAny) -> ValResult<'py, Self> {
+    pub fn new_value(py_value: &'py PyAny) -> ValResult<Self> {
         if let Ok(py_str) = py_value.downcast::<PyString>() {
             Ok(Self::String(py_str))
         } else if let Ok(value) = py_value.downcast::<PyDict>() {
@@ -63,10 +62,10 @@ impl AsLocItem for StringMapping<'_> {
 }
 
 impl<'a> Input<'a> for StringMapping<'a> {
-    fn as_error_value(&'a self) -> InputValue<'a> {
+    fn as_error_value(&self) -> InputValue {
         match self {
             Self::String(s) => s.as_error_value(),
-            Self::Mapping(d) => InputValue::PyAny(d),
+            Self::Mapping(d) => d.as_error_value(),
         }
     }
 
@@ -74,28 +73,18 @@ impl<'a> Input<'a> for StringMapping<'a> {
         None
     }
 
-    fn validate_args(&'a self) -> ValResult<'a, GenericArguments<'a>> {
+    fn validate_args(&'a self) -> ValResult<GenericArguments<'a>> {
         // do we want to support this?
         Err(ValError::new(ErrorTypeDefaults::ArgumentsType, self))
     }
 
-    fn validate_dataclass_args(&'a self, _dataclass_name: &str) -> ValResult<'a, GenericArguments<'a>> {
+    fn validate_dataclass_args(&'a self, _dataclass_name: &str) -> ValResult<GenericArguments<'a>> {
         match self {
             StringMapping::String(_) => Err(ValError::new(ErrorTypeDefaults::ArgumentsType, self)),
             StringMapping::Mapping(m) => Ok(GenericArguments::StringMapping(m)),
         }
     }
 
-    fn parse_json(&'a self) -> ValResult<'a, JsonValue> {
-        match self {
-            Self::String(s) => {
-                let str = py_string_str(s)?;
-                JsonValue::parse(str.as_bytes(), true).map_err(|e| map_json_err(self, e))
-            }
-            Self::Mapping(_) => Err(ValError::new(ErrorTypeDefaults::JsonType, self)),
-        }
-    }
-
     fn validate_str(
         &'a self,
         _strict: bool,
@@ -114,14 +103,14 @@ impl<'a> Input<'a> for StringMapping<'a> {
         }
     }
 
-    fn validate_bool(&self, _strict: bool) -> ValResult<'_, ValidationMatch<bool>> {
+    fn validate_bool(&self, _strict: bool) -> ValResult<ValidationMatch<bool>> {
         match self {
             Self::String(s) => str_as_bool(self, py_string_str(s)?).map(ValidationMatch::strict),
             Self::Mapping(_) => Err(ValError::new(ErrorTypeDefaults::BoolType, self)),
         }
     }
 
-    fn validate_int(&'a self, _strict: bool) -> ValResult<'a, ValidationMatch<EitherInt<'a>>> {
+    fn validate_int(&'a self, _strict: bool) -> ValResult<ValidationMatch<EitherInt<'a>>> {
         match self {
             Self::String(s) => match py_string_str(s)?.parse() {
                 Ok(i) => Ok(ValidationMatch::strict(EitherInt::I64(i))),
@@ -131,7 +120,7 @@ impl<'a> Input<'a> for StringMapping<'a> {
         }
     }
 
-    fn validate_float(&'a self, _strict: bool) -> ValResult<'a, ValidationMatch<EitherFloat<'a>>> {
+    fn validate_float(&'a self, _strict: bool) -> ValResult<ValidationMatch<EitherFloat<'a>>> {
         match self {
             Self::String(s) => str_as_float(self, py_string_str(s)?).map(ValidationMatch::strict),
             Self::Mapping(_) => Err(ValError::new(ErrorTypeDefaults::FloatType, self)),
