@@ -51,12 +51,6 @@ impl fmt::Display for LookupKey {
     }
 }
 
-macro_rules! py_string {
-    ($py:ident, $str:expr) => {
-        PyString::intern($py, $str).into()
-    };
-}
-
 impl LookupKey {
     pub fn from_py(py: Python, value: &PyAny, alt_alias: Option<&str>) -> PyResult<Self> {
         if let Ok(alias_py) = value.downcast::<PyString>() {
@@ -67,7 +61,7 @@ impl LookupKey {
                     py_key1: alias_py.into_py(py),
                     path1: LookupPath::from_str(py, alias, Some(alias_py)),
                     key2: alt_alias.to_string(),
-                    py_key2: py_string!(py, alt_alias),
+                    py_key2: PyString::new(py, alt_alias).into(),
                     path2: LookupPath::from_str(py, alt_alias, None),
                 }),
                 None => Ok(Self::simple(py, alias, Some(alias_py))),
@@ -98,12 +92,12 @@ impl LookupKey {
 
     fn simple(py: Python, key: &str, opt_py_key: Option<&PyString>) -> Self {
         let py_key = match opt_py_key {
-            Some(py_key) => py_key.into_py(py),
-            None => py_string!(py, key),
+            Some(py_key) => py_key,
+            None => PyString::new(py, key),
         };
         Self::Simple {
             key: key.to_string(),
-            py_key,
+            py_key: py_key.into(),
             path: LookupPath::from_str(py, key, opt_py_key),
         }
     }
@@ -111,7 +105,7 @@ impl LookupKey {
     pub fn py_get_dict_item<'data, 's>(
         &'s self,
         dict: &'data PyDict,
-    ) -> ValResult<'data, Option<(&'s LookupPath, &'data PyAny)>> {
+    ) -> ValResult<Option<(&'s LookupPath, &'data PyAny)>> {
         match self {
             Self::Simple { py_key, path, .. } => match dict.get_item(py_key)? {
                 Some(value) => Ok(Some((path, value))),
@@ -148,7 +142,7 @@ impl LookupKey {
     pub fn py_get_string_mapping_item<'data, 's>(
         &'s self,
         dict: &'data PyDict,
-    ) -> ValResult<'data, Option<(&'s LookupPath, StringMapping<'data>)>> {
+    ) -> ValResult<Option<(&'s LookupPath, StringMapping<'data>)>> {
         if let Some((path, py_any)) = self.py_get_dict_item(dict)? {
             let value = StringMapping::new_value(py_any)?;
             Ok(Some((path, value)))
@@ -160,7 +154,7 @@ impl LookupKey {
     pub fn py_get_mapping_item<'data, 's>(
         &'s self,
         dict: &'data PyMapping,
-    ) -> ValResult<'data, Option<(&'s LookupPath, &'data PyAny)>> {
+    ) -> ValResult<Option<(&'s LookupPath, &'data PyAny)>> {
         match self {
             Self::Simple { py_key, path, .. } => match dict.get_item(py_key) {
                 Ok(value) => Ok(Some((path, value))),
@@ -198,7 +192,7 @@ impl LookupKey {
         &'s self,
         obj: &'data PyAny,
         kwargs: Option<&'data PyDict>,
-    ) -> ValResult<'data, Option<(&'s LookupPath, &'data PyAny)>> {
+    ) -> ValResult<Option<(&'s LookupPath, &'data PyAny)>> {
         match self._py_get_attr(obj, kwargs) {
             Ok(v) => Ok(v),
             Err(err) => {
@@ -266,7 +260,7 @@ impl LookupKey {
     pub fn json_get<'data, 's>(
         &'s self,
         dict: &'data JsonObject,
-    ) -> ValResult<'data, Option<(&'s LookupPath, &'data JsonValue)>> {
+    ) -> ValResult<Option<(&'s LookupPath, &'data JsonValue)>> {
         match self {
             Self::Simple { key, path, .. } => match dict.get(key) {
                 Some(value) => Ok(Some((path, value))),
@@ -316,7 +310,7 @@ impl LookupKey {
         input: &'d impl Input<'d>,
         loc_by_alias: bool,
         field_name: &str,
-    ) -> ValLineError<'d> {
+    ) -> ValLineError {
         if loc_by_alias {
             let lookup_path = match self {
                 Self::Simple { path, .. } => path,
@@ -348,10 +342,10 @@ impl fmt::Display for LookupPath {
 impl LookupPath {
     fn from_str(py: Python, key: &str, py_key: Option<&PyString>) -> Self {
         let py_key = match py_key {
-            Some(py_key) => py_key.into_py(py),
-            None => py_string!(py, key),
+            Some(py_key) => py_key,
+            None => PyString::new(py, key),
         };
-        Self(vec![PathItem::S(key.to_string(), py_key)])
+        Self(vec![PathItem::S(key.to_string(), py_key.into())])
     }
 
     fn from_list(obj: &PyAny) -> PyResult<LookupPath> {
@@ -369,12 +363,7 @@ impl LookupPath {
         }
     }
 
-    pub fn apply_error_loc<'a>(
-        &self,
-        mut line_error: ValLineError<'a>,
-        loc_by_alias: bool,
-        field_name: &str,
-    ) -> ValLineError<'a> {
+    pub fn apply_error_loc(&self, mut line_error: ValLineError, loc_by_alias: bool, field_name: &str) -> ValLineError {
         if loc_by_alias {
             for path_item in self.iter().rev() {
                 line_error = line_error.with_outer_location(path_item.clone().into());
@@ -440,7 +429,7 @@ impl PathItem {
             } else {
                 Ok(Self::Pos(usize_key))
             }
-        } else if let Ok(int_key) = extract_i64(obj) {
+        } else if let Some(int_key) = extract_i64(obj) {
             if index == 0 {
                 py_err!(PyTypeError; "The first item in an alias path should be a string")
             } else {
