@@ -67,6 +67,7 @@ impl BuildValidator for CallValidator {
 }
 
 impl_py_gc_traverse!(CallValidator {
+    function,
     arguments_validator,
     return_validator
 });
@@ -77,7 +78,7 @@ impl Validator for CallValidator {
         py: Python<'data>,
         input: &'data impl Input<'data>,
         state: &mut ValidationState,
-    ) -> ValResult<'data, PyObject> {
+    ) -> ValResult<PyObject> {
         let args = self.arguments_validator.validate(py, input, state)?;
 
         let return_value = if let Ok((args, kwargs)) = args.extract::<(&PyTuple, &PyDict)>(py) {
