@@ -60,6 +60,7 @@ pub struct ModelValidator {
     frozen: bool,
     custom_init: bool,
     root_model: bool,
+    undefined: PyObject,
     name: String,
 }
 
@@ -89,10 +90,11 @@ impl BuildValidator for ModelValidator {
             class: class.into(),
             post_init: schema
                 .get_as::<&str>(intern!(py, "post_init"))?
-                .map(|s| PyString::intern(py, s).into_py(py)),
+                .map(|s| PyString::new(py, s).into_py(py)),
             frozen: schema.get_as(intern!(py, "frozen"))?.unwrap_or(false),
             custom_init: schema.get_as(intern!(py, "custom_init"))?.unwrap_or(false),
             root_model: schema.get_as(intern!(py, "root_model"))?.unwrap_or(false),
+            undefined: PydanticUndefinedType::new(py).to_object(py),
             // Get the class's `__name__`, not using `class.name()` since it uses `__qualname__`
             // which is not what we want here
             name: class.getattr(intern!(py, "__name__"))?.extract()?,
@@ -109,7 +111,7 @@ impl Validator for ModelValidator {
         py: Python<'data>,
         input: &'data impl Input<'data>,
         state: &mut ValidationState,
-    ) -> ValResult<'data, PyObject> {
+    ) -> ValResult<PyObject> {
         if let Some(self_instance) = state.extra().self_instance {
             // in the case that self_instance is Some, we're calling validation from within `BaseModel.__init__`
             return self.validate_init(py, self_instance, input, state);
@@ -157,7 +159,7 @@ impl Validator for ModelValidator {
         field_name: &'data str,
         field_value: &'data PyAny,
         state: &mut ValidationState,
-    ) -> ValResult<'data, PyObject> {
+    ) -> ValResult<PyObject> {
         if self.frozen {
             return Err(ValError::new(ErrorTypeDefaults::FrozenInstance, field_value));
         } else if self.root_model {
@@ -222,14 +224,14 @@ impl ModelValidator {
         self_instance: &'s PyAny,
         input: &'data impl Input<'data>,
         state: &mut ValidationState,
-    ) -> ValResult<'data, PyObject> {
+    ) -> ValResult<PyObject> {
         // we need to set `self_instance` to None for nested validators as we don't want to operate on self_instance
         // anymore
         let state = &mut state.rebind_extra(|extra| extra.self_instance = None);
         let output = self.validator.validate(py, input, state)?;
 
         if self.root_model {
-            let fields_set = if input.to_object(py).is(&PydanticUndefinedType::py_undefined()) {
+            let fields_set = if input.to_object(py).is(&self.undefined) {
                 PySet::empty(py)?
             } else {
                 PySet::new(py, [&String::from(ROOT_FIELD)])?
@@ -249,7 +251,7 @@ impl ModelValidator {
         input: &'data impl Input<'data>,
         existing_fields_set: Option<&'data PyAny>,
         state: &mut ValidationState,
-    ) -> ValResult<'data, PyObject> {
+    ) -> ValResult<PyObject> {
         if self.custom_init {
             // If we wanted, we could introspect the __init__ signature, and store the
             // keyword arguments and types, and create a validator for them.
@@ -270,7 +272,7 @@ impl ModelValidator {
         let instance_ref = instance.as_ref(py);
 
         if self.root_model {
-            let fields_set = if input.to_object(py).is(&PydanticUndefinedType::py_undefined()) {
+            let fields_set = if input.to_object(py).is(&self.undefined) {
                 PySet::empty(py)?
             } else {
                 PySet::new(py, [&String::from(ROOT_FIELD)])?
@@ -291,7 +293,7 @@ impl ModelValidator {
         instance: PyObject,
         input: &'data impl Input<'data>,
         extra: &Extra,
-    ) -> ValResult<'data, PyObject> {
+    ) -> ValResult<PyObject> {
         if let Some(ref post_init) = self.post_init {
             instance
                 .call_method1(py, post_init.as_ref(py), (extra.context,))
