@@ -4,7 +4,7 @@ from functools import partial
 
 import pytest
 
-from pydantic_core import SchemaError, SchemaSerializer, core_schema
+from pydantic_core import SchemaError, SchemaSerializer, core_schema, validate_core_schema
 
 
 def test_list_any():
@@ -144,8 +144,10 @@ def test_exclude(schema_func, seq_f):
 @pytest.mark.parametrize('include,exclude', [({1, 3, 5}, {5, 6}), ([1, 3, 5], [5, 6])])
 def test_filter(include, exclude):
     v = SchemaSerializer(
-        core_schema.list_schema(
-            core_schema.any_schema(), serialization=core_schema.filter_seq_schema(include=include, exclude=exclude)
+        validate_core_schema(
+            core_schema.list_schema(
+                core_schema.any_schema(), serialization=core_schema.filter_seq_schema(include=include, exclude=exclude)
+            )
         )
     )
     assert v.to_python([0, 1, 2, 3, 4, 5, 6, 7]) == [1, 3]
@@ -186,7 +188,7 @@ class RemovedContains(ImplicitContains):
 @pytest.mark.parametrize('schema_func', [core_schema.list_schema, core_schema.tuple_variable_schema])
 def test_include_error(schema_func, include_value, error_msg):
     with pytest.raises(SchemaError, match=error_msg):
-        SchemaSerializer(
+        validate_core_schema(
             schema_func(core_schema.any_schema(), serialization=core_schema.filter_seq_schema(include=include_value))
         )
 
@@ -327,19 +329,20 @@ def test_filter_list_of_dicts():
 
 
 def test_positional_tuple():
-    s = SchemaSerializer(
-        {'type': 'tuple-positional', 'items_schema': [{'type': 'int'}, {'type': 'bytes'}, {'type': 'float'}]}
-    )
+    s = SchemaSerializer({'type': 'tuple', 'items_schema': [{'type': 'int'}, {'type': 'bytes'}, {'type': 'float'}]})
     assert s.to_python((1, b'2', 3.0)) == (1, b'2', 3.0)
-    assert s.to_python((1, b'2', 3.0, 123)) == (1, b'2', 3.0, 123)
+    with pytest.warns(UserWarning, match='Unexpected extra items present in tuple'):
+        assert s.to_python((1, b'2', 3.0, 123)) == (1, b'2', 3.0, 123)
     assert s.to_python((1, b'2')) == (1, b'2')
 
     assert s.to_python((1, b'2', 3.0), mode='json') == [1, '2', 3.0]
-    assert s.to_python((1, b'2', 3.0, 123), mode='json') == [1, '2', 3.0, 123]
+    with pytest.warns(UserWarning, match='Unexpected extra items present in tuple'):
+        assert s.to_python((1, b'2', 3.0, 123), mode='json') == [1, '2', 3.0, 123]
     assert s.to_python((1, b'2'), mode='json') == [1, '2']
 
     assert s.to_json((1, b'2', 3.0)) == b'[1,"2",3.0]'
-    assert s.to_json((1, b'2', 3.0, 123)) == b'[1,"2",3.0,123]'
+    with pytest.warns(UserWarning, match='Unexpected extra items present in tuple'):
+        assert s.to_json((1, b'2', 3.0, 123)) == b'[1,"2",3.0,123]'
     assert s.to_json((1, b'2')) == b'[1,"2"]'
 
 
@@ -349,7 +352,7 @@ def test_function_positional_tuple():
 
     s = SchemaSerializer(
         {
-            'type': 'tuple-positional',
+            'type': 'tuple',
             'items_schema': [
                 core_schema.any_schema(
                     serialization=core_schema.plain_serializer_function_ser_schema(partial(f, 'a'), info_arg=True)
@@ -357,10 +360,11 @@ def test_function_positional_tuple():
                 core_schema.any_schema(
                     serialization=core_schema.plain_serializer_function_ser_schema(partial(f, 'b'), info_arg=True)
                 ),
+                core_schema.any_schema(
+                    serialization=core_schema.plain_serializer_function_ser_schema(partial(f, 'extra'), info_arg=True)
+                ),
             ],
-            'extra_schema': core_schema.any_schema(
-                serialization=core_schema.plain_serializer_function_ser_schema(partial(f, 'extra'), info_arg=True)
-            ),
+            'variadic_item_index': 2,
         }
     )
     assert s.to_python((1,)) == ('a1',)
@@ -396,7 +400,7 @@ def test_tuple_pos_dict_key():
     s = SchemaSerializer(
         core_schema.dict_schema(
             core_schema.tuple_positional_schema(
-                [core_schema.int_schema(), core_schema.str_schema()], extra_schema=core_schema.int_schema()
+                [core_schema.int_schema(), core_schema.str_schema()], extras_schema=core_schema.int_schema()
             ),
             core_schema.int_schema(),
         )
