@@ -148,12 +148,12 @@ def generate_repeats():
         (
             {'max_length': 3},
             {1, 2, 3, 4},
-            Err('Frozenset should have at most 3 items after validation, not 4 [type=too_long,'),
+            Err('Frozenset should have at most 3 items after validation, not more [type=too_long,'),
         ),
         (
             {'items_schema': {'type': 'int'}, 'max_length': 3},
             {1, 2, 3, 4},
-            Err('Frozenset should have at most 3 items after validation, not 4 [type=too_long,'),
+            Err('Frozenset should have at most 3 items after validation, not more [type=too_long,'),
         ),
         # length check after set creation
         ({'max_length': 3}, [1, 1, 2, 2, 3, 3], {1, 2, 3}),
@@ -161,7 +161,7 @@ def generate_repeats():
         (
             {'max_length': 3},
             infinite_generator(),
-            Err('Frozenset should have at most 3 items after validation, not 4 [type=too_long,'),
+            Err('Frozenset should have at most 3 items after validation, not more [type=too_long,'),
         ),
     ],
 )
@@ -276,13 +276,13 @@ def test_generator_error():
     [
         pytest.param(
             {1: 10, 2: 20, '3': '30'}.items(),
-            {'type': 'tuple-variable', 'items_schema': {'type': 'any'}},
+            {'type': 'tuple', 'items_schema': [{'type': 'any'}], 'variadic_item_index': 0},
             frozenset(((1, 10), (2, 20), ('3', '30'))),
             id='Tuple[Any, Any]',
         ),
         pytest.param(
             {1: 10, 2: 20, '3': '30'}.items(),
-            {'type': 'tuple-variable', 'items_schema': {'type': 'int'}},
+            {'type': 'tuple', 'items_schema': [{'type': 'int'}], 'variadic_item_index': 0},
             frozenset(((1, 10), (2, 20), (3, 30))),
             id='Tuple[int, int]',
         ),
